@@ -3,7 +3,9 @@
 #ifndef PREFERENCES_DIALOG_H
 #define PREFERENCES_DIALOG_H
 
-#include <qstring.h>
+
+//Added by qt3to4:
+#include <QShowEvent>
 #include <kdialogbase.h>
 
 class QPushButton;
