@@ -24,13 +24,17 @@
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
+
 #include "images.moc"
 #include <ui.h>
-#include <qwhatsthis.h>
-#include <qregexp.h>
-#include <qstring.h>
+
+#include <QRegExp>
+
+//Added by qt3to4:
+#include <QHBoxLayout>
+#include <kvbox.h>
 
 #ifdef USE_KDE
 #include "kde/InputBox.h"
@@ -40,63 +44,63 @@
 #include "qt/Details.h"
 #endif
 
-Images::Images(liloconf *l, QWidget *parent, const char *name):QWidget(parent, name)
+Images::Images(liloconf *l, QWidget *parent):QWidget(parent)
 {
-	current=""; previous=""; // Using QString::null gives problems!
+	current=""; previous=""; // Using QString() gives problems!
 	lilo=l;
 	layout=new QHBoxLayout(this);
 	layout->setMargin(SPACE_MARGIN);
 	layout->setSpacing(SPACE_INSIDE);
-	images=new QListBox(this);
+	images=new Q3ListBox(this);
 	layout->addWidget(images, 1);
 	connect(images, SIGNAL(highlighted(const QString &)), SLOT(imageSelected(const QString &)));
-	QWhatsThis::add(images, _("This is the list of kernels and operating systems you can currently boot. Select which one you want to edit here."));
+	images->setWhatsThis( _("This is the list of kernels and operating systems you can currently boot. Select which one you want to edit here."));
 
-	parameters=new QVBox(this);
-	parameters->setMargin(SPACE_MARGIN);
+	parameters=new KVBox(this);
+	//parameters->setMargin(SPACE_MARGIN);
 	parameters->setSpacing(SPACE_INSIDE);
 	layout->addWidget(parameters, 2);
 	image=new EditWidget(_("&Kernel:"), "", true, parameters);
-	QWhatsThis::add(image, _("Enter the filename of the kernel you want to boot here."));
+	image->setWhatsThis( _("Enter the filename of the kernel you want to boot here."));
 	connect(image, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
 	label=new EditWidget(_("&Label:"), "", false, parameters);
-	QWhatsThis::add(label, _("Enter the label (name) of the kernel you want to boot here."));
+	label->setWhatsThis( _("Enter the label (name) of the kernel you want to boot here."));
 	connect(label, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
 	root=new EditWidget(_("&Root filesystem:"), "", true, parameters);
-	QWhatsThis::add(root, _("Enter the root filesystem (i.e. the partition that will be mounted as / at boot time) for the kernel you want to boot here."));
+	root->setWhatsThis( _("Enter the root filesystem (i.e. the partition that will be mounted as / at boot time) for the kernel you want to boot here."));
 	connect(root, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
 	initrd=new EditWidget(_("&Initial ramdisk:"), "", true, parameters);
-	QWhatsThis::add(initrd, _("If you want to use an initial ramdisk (initrd) for this kernel, enter its filename here. Leave this field blank if you don't intend to use an initial ramdisk for this kernel."));
+	initrd->setWhatsThis( _("If you want to use an initial ramdisk (initrd) for this kernel, enter its filename here. Leave this field blank if you don't intend to use an initial ramdisk for this kernel."));
 	connect(initrd, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
 	append=new EditWidget(_("E&xtra parameters:"), "", false, parameters);
-	QWhatsThis::add(append, _("Enter any extra parameters you wish to pass to the kernel here. Usually, this can be left blank.<br>This sets the <i>append</i> option in lilo.conf."));
+	append->setWhatsThis( _("Enter any extra parameters you wish to pass to the kernel here. Usually, this can be left blank.<br>This sets the <i>append</i> option in lilo.conf."));
 	connect(append, SIGNAL(textChanged(const QString &)), this, SIGNAL(configChanged()));
 
-	actions=new QVBox(this);
-	actions->setMargin(SPACE_MARGIN);
+	actions=new KVBox(this);
+	//actions->setMargin(SPACE_MARGIN);
 	actions->setSpacing(SPACE_INSIDE);
 	layout->addWidget(actions);
 	dflt=new QPushButton(_("Set &Default"), actions);
-	QWhatsThis::add(dflt, _("Boot this kernel/OS if the user doesn't make a different choice"));
+	dflt->setWhatsThis( _("Boot this kernel/OS if the user doesn't make a different choice"));
 	connect(dflt, SIGNAL(clicked()), SLOT(dfltClicked()));
 	details=new QPushButton(_("De&tails"), actions);
-	QWhatsThis::add(details, _("This button brings up a dialog box with further, less commonly used, options."));
+	details->setWhatsThis( _("This button brings up a dialog box with further, less commonly used, options."));
 	connect(details, SIGNAL(clicked()), SLOT(detailsClicked()));
 	probe=new QPushButton(_("&Probe"), actions);
 	connect(probe, SIGNAL(clicked()), SLOT(probeClicked()));
-	QWhatsThis::add(probe, _("Automatically generate a (hopefully) reasonable lilo.conf for your system"));
+	probe->setWhatsThis( _("Automatically generate a (hopefully) reasonable lilo.conf for your system"));
 	check=new QPushButton(_("&Check Configuration"), actions);
 	connect(check, SIGNAL(clicked()), SLOT(checkClicked()));
-	QWhatsThis::add(check, _("Run LILO in test mode to see if the configuration is ok"));
+	check->setWhatsThis( _("Run LILO in test mode to see if the configuration is ok"));
 	addKrnl=new QPushButton(_("Add &Kernel..."), actions);
 	connect(addKrnl, SIGNAL(clicked()), SLOT(addKrnlClicked()));
-	QWhatsThis::add(addKrnl, _("Add a new Linux kernel to the boot menu"));
+	addKrnl->setWhatsThis( _("Add a new Linux kernel to the boot menu"));
 	addOS=new QPushButton(_("Add Other &OS..."), actions);
 	connect(addOS, SIGNAL(clicked()), SLOT(addOSClicked()));
-	QWhatsThis::add(addOS, _("Add a non-Linux OS to the boot menu"));
+	addOS->setWhatsThis( _("Add a non-Linux OS to the boot menu"));
 	remove=new QPushButton(_("&Remove Entry"), actions);
 	connect(remove, SIGNAL(clicked()), SLOT(removeClicked()));
-	QWhatsThis::add(remove, _("Remove entry from the boot menu"));
+	remove->setWhatsThis( _("Remove entry from the boot menu"));
 	update();
 }
 Images::~Images()
@@ -131,13 +135,14 @@ void Images::probeClicked() // SLOT
 void Images::dfltClicked() // SLOT
 {
 	if (images->currentItem() < 0) return;
-	lilo->setDefault(images->currentText().replace(QRegExp(" (default)", true, true), "").latin1());
+	lilo->setDefault(images->currentText().replace(QRegExp(" (default)", true, true),
+                    "").toLatin1().data());
 	update();
 	emit configChanged();
 }
 void Images::detailsClicked() // SLOT
 {
-	liloimage *l=lilo->images[current.latin1()];
+	liloimage *l=lilo->images[current.toLatin1().data()];
 	Details *d = new Details(l, this);
 	if(d->exec()==QDialog::Accepted) {
 		String tmp;
@@ -146,7 +151,7 @@ void Images::detailsClicked() // SLOT
 			l->insert(l->end(), "\tread-only");
 		else if(!d->isReadOnly() && !tmp.empty())
 			l->remove(tmp);
-		l->set("vga", d->vgaMode().latin1(), true, true, "\t");
+		l->set("vga", d->vgaMode().toLatin1().data(), true, true, "\t");
 		tmp=l->grep("^[ \t]*unsafe[ \t]*");
 		if(d->isUnsafe() && tmp.empty())
 			l->insert(l->end(), "\tunsafe");
@@ -163,9 +168,9 @@ void Images::detailsClicked() // SLOT
 		else if(!d->isRestricted() && !tmp.empty())
 			l->remove(tmp);
 		if(d->isRestricted() || d->usePassword())
-			l->set("password", d->Password().latin1(), true, true, "\t");
+			l->set("password", d->Password().toLatin1().data(), true, true, "\t");
 
-		l->set("password", d->Password().latin1(), true, true, "\t");
+		l->set("password", d->Password().toLatin1().data(), true, true, "\t");
 		emit configChanged();
 	}
 	delete d;
@@ -196,13 +201,13 @@ void Images::addKrnlClicked() // SLOT
 	if(label->exec()==QDialog::Accepted) {
 		QStringList s=label->text();
 		QStringList::Iterator it=s.begin();
-		String kernel=(*it).latin1();
+		String kernel=(*it).toLatin1().data();
 		it++;
-		String label=(*it).latin1();
+		String label=(*it).toLatin1().data();
 		it++;
-		String root=(*it).latin1();
+		String root=(*it).toLatin1().data();
 		it++;
-		String initrd=(*it).latin1();
+		String initrd=(*it).toLatin1().data();
 		lilo->addLinux(label, kernel, root, initrd);
 		update();
 		emit configChanged();
@@ -220,9 +225,9 @@ void Images::addOSClicked() // SLOT
 	if(label->exec()==QDialog::Accepted) {
 		QStringList s=label->text();
 		QStringList::Iterator it=s.begin();
-		String disk=(*it).latin1();
+		String disk=(*it).toLatin1().data();
 		it++;
-		String label=(*it).latin1();
+		String label=(*it).toLatin1().data();
 		lilo->addOther(label, disk);
 		update();
 		emit configChanged();
@@ -238,7 +243,7 @@ void Images::removeClicked() // SLOT
 		s=s.left(s.length()-10);
         if (s.isNull())
 		s = "";
-	lilo->images.remove(s.latin1());
+	lilo->images.remove(s.toLatin1().data());
 	previous=""; current="";
 	update();
 	emit configChanged();
@@ -272,7 +277,7 @@ void Images::imageSelected(const QString &i) // SLOT
         if (s.isNull())
 		s = "";
 	current=s;
-	liloimage *l=lilo->images[s.latin1()];
+	liloimage *l=lilo->images[s.toLatin1().data()];
 	if(l) {
 		QString img=value(l->grep("^[ \t]*(image|other)[ \t]*=").cstr());
 		image->setText(img);
@@ -305,13 +310,13 @@ void Images::imageSelected(const QString &i) // SLOT
 void Images::saveChanges() // SLOT
 {
 	if(!current.isEmpty()) {
-		liloimage *l=lilo->images[current.latin1()];
+		liloimage *l=lilo->images[current.toLatin1().data()];
 		if(l) {
-			l->set("image", image->text().latin1(), true, true);
-			l->set("label", label->text().latin1(), true, true, "\t");
-			l->set("root", root->text().latin1(), true, true, "\t");
-			l->set("initrd", initrd->text().latin1(), true, true, "\t");
-			l->set("append", append->text().latin1(), true, true, "\t");
+			l->set("image", image->text().toLatin1().data(), true, true);
+			l->set("label", label->text().toLatin1().data(), true, true, "\t");
+			l->set("root", root->text().toLatin1().data(), true, true, "\t");
+			l->set("initrd", initrd->text().toLatin1().data(), true, true, "\t");
+			l->set("append", append->text().toLatin1().data(), true, true, "\t");
 		}
 	}
 }
